@@ -111,6 +111,7 @@ void Config::load()
     }
     data.advanced.maxSizeForSharedMemoryTempFiles = group.readEntry( "maxSizeForSharedMemoryTempFiles", data.advanced.sharedMemorySize / 4 );
     data.advanced.usePipes = group.readEntry( "usePipes", false );
+    data.advanced.ejectCdAfterRip = group.readEntry( "ejectCdAfterRip", true );
 
     group = conf->group( "CoverArt" );
     data.coverArt.writeCovers = group.readEntry( "writeCovers", 1 );
@@ -118,7 +119,6 @@ void Config::load()
     data.coverArt.writeCoverDefaultName = group.readEntry( "writeCoverDefaultName", i18nc("cover file name","cover") );
 
     group = conf->group( "Backends" );
-    data.backends.rippers = group.readEntry( "rippers", QStringList() );
     formats = group.readEntry( "formats", QStringList() );
     foreach( const QString format, formats )
     {
@@ -135,7 +135,6 @@ void Config::load()
     pPluginLoader->load();
 
     QString pluginName;
-    bool found;
     QStringList enabledPlugins;
     QStringList newPlugins;
     int codecIndex;
@@ -144,42 +143,6 @@ void Config::load()
 
     // build default backend priority list
 
-    // rippers
-    enabledPlugins.clear();
-    newPlugins.clear();
-    // register existing enabled plugins as such and list new enabled plugins
-    foreach( RipperPlugin *plugin, pPluginLoader->getAllRipperPlugins() )
-    {
-        pluginName = plugin->name();
-        foreach( const ConversionPipeTrunk trunk, plugin->codecTable() )
-        {
-            if( trunk.enabled )
-            {
-                enabledPlugins += pluginName;
-                if( !data.backends.rippers.contains(pluginName) && newPlugins.filter(QRegExp("[0-9]{8,8}"+pluginName)).count()==0 )
-                {
-                    newPlugins += QString::number(trunk.rating).rightJustified(8,'0') + pluginName;
-                    break;
-                }
-            }
-        }
-    }
-    // remove plugins from the ripper list if they aren't enabled any more
-    for( int i=0; i<data.backends.rippers.count(); i++ )
-    {
-        if( !enabledPlugins.contains(data.backends.rippers.at(i)) )
-        {
-            data.backends.rippers.removeAt(i);
-            i--;
-        }
-    }
-    // sort new enabled plugins and append them to the ripper list
-    newPlugins.sort();
-    for( int i=0; i<newPlugins.count(); i++ )
-    {
-        data.backends.rippers += newPlugins.at(i).right(newPlugins.at(i).length()-8);
-    }
-
     foreach( const QString format, formats )
     {
         if( format == "wav" )
@@ -545,6 +508,7 @@ void Config::save()
     group.writeEntry( "useSharedMemoryForTempFiles", data.advanced.useSharedMemoryForTempFiles );
     group.writeEntry( "maxSizeForSharedMemoryTempFiles", data.advanced.maxSizeForSharedMemoryTempFiles );
     group.writeEntry( "usePipes", data.advanced.usePipes );
+    group.writeEntry( "ejectCdAfterRip", data.advanced.ejectCdAfterRip );
 
     group = conf->group( "CoverArt" );
     group.writeEntry( "writeCovers", data.coverArt.writeCovers );
@@ -552,7 +516,7 @@ void Config::save()
     group.writeEntry( "writeCoverDefaultName", data.coverArt.writeCoverDefaultName );
 
     group = conf->group( "Backends" );
-    group.writeEntry( "rippers", data.backends.rippers );
+    group.deleteEntry( "rippers" );
     QStringList formats;
     foreach( const CodecData codec, data.backends.codecs )
     {
