@@ -11,9 +11,19 @@
 //
 #include "configpagebase.h"
 
+#include <QApplication>
+
+
 ConfigPageBase::ConfigPageBase( QWidget *parent )
  : QWidget( parent )
-{}
+{
+    const int fontHeight = QFontMetrics(QApplication::font()).boundingRect("M").size().height();
+
+    spacingOffset = 2 * fontHeight;
+    spacingSmall  = 0.5*fontHeight;
+    spacingMedium =     fontHeight;
+    spacingBig    = 2 * fontHeight;
+}
 
 ConfigPageBase::~ConfigPageBase()
 {}
