@@ -14,16 +14,9 @@ ReplayGainPluginItem::~ReplayGainPluginItem()
 {}
 
 
-//
-// class ReplayGainPlugin
-//
-////////////////////
-
 ReplayGainPlugin::ReplayGainPlugin( QObject *parent )
     : BackendPlugin( parent )
-{
-    lastId = 0;
-}
+{}
 
 ReplayGainPlugin::~ReplayGainPlugin()
 {}
