@@ -49,17 +49,14 @@ public:
     };
 
     ReplayGainPlugin( QObject *parent=0 );
-    ~ReplayGainPlugin();
+    virtual ~ReplayGainPlugin();
 
     virtual QString type();
 
     virtual QList<ReplayGainPipe> codecTable() = 0;
 
-    /** converts a file; TODO notify Conversion when the process has been finished */
-    virtual int apply( const KUrl::List& fileList, ApplyMode mode = Add ) = 0;
-
-protected:
-    int lastId;
+    /** adds replaygain to one or more files */
+    virtual unsigned int apply( const KUrl::List& fileList, ApplyMode mode = Add ) = 0;
 };
 
 #define K_EXPORT_SOUNDKONVERTER_REPLAYGAIN(libname, classname) \
