@@ -23,7 +23,7 @@ public:
     LogViewer( Logger* _logger, QWidget* parent=0, Qt::WFlags f=0 );
 
     /** Default Destructor */
-    virtual ~LogViewer();
+    ~LogViewer();
 
 private:
     Logger* logger;
@@ -40,6 +40,8 @@ private slots:
 public slots:
     /** get notification when a job has been removed */
     void processRemoved( int id );
+    /** show the corresponding log */
+    void showLog( int id );
 };
 
 #endif // LOGVIEWER_H
