@@ -4,7 +4,9 @@
 #include "core/conversionoptions.h"
 #include "config.h"
 
+#include <QApplication>
 #include <QLayout>
+#include <QHBoxLayout>
 #include <QDir>
 #include <QFileInfo>
 #include <QString>
@@ -118,6 +120,8 @@ QString OutputDirectory::filesystemForDirectory( const QString& dir )
 
 KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, const QStringList& usedOutputNames )
 {
+    QRegExp regEx( "%[abcdfgnpsty]{1,1}", Qt::CaseInsensitive );
+
     ConversionOptions *options = config->conversionOptionsManager()->getConversionOptions(fileListItem->conversionOptionsId);
     if( !options )
         return KUrl();
@@ -145,7 +149,7 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, cons
         if( config->data.general.useVFATNames || options->outputFilesystem == "vfat" )
             path = vfatPath( path );
 
-        if( options->outputFilesystem == "ntfs" )
+        if( options->outputFilesystem == "ntfs" || options->outputFilesystem == "fuseblk" )
             path = ntfsPath( path );
 
         url = changeExtension( KUrl(path), extension );
@@ -163,7 +167,7 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, cons
         // TODO these restrictions could be a little bit over the top
         if( path.right(1) == "/" )
             path += "%f";
-        else if( path.lastIndexOf(QRegExp("%[abcdfgnpty]")) < path.lastIndexOf("/") )
+        else if( path.lastIndexOf(regEx) < path.lastIndexOf("/") )
             path += "/%f";
 
         const int fileNameBegin = path.lastIndexOf("/");
@@ -178,13 +182,14 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, cons
         path.replace( "\\[", "$quared_bracket_open$" );
         path.replace( "\\]", "$quared_bracket_close$" );
 
-        QRegExp reg( "\\[(.*)%([abcdfgnpty])(.*)\\]" );
+        QRegExp reg( "\\[(.*)%([abcdfgnpsty])(.*)\\]", Qt::CaseInsensitive );
         reg.setMinimal( true );
         while( path.indexOf(reg) != -1 )
         {
             if( fileListItem->tags &&
                 (
                   ( reg.cap(2) == "a" && !fileListItem->tags->artist.isEmpty() ) ||
+                  ( reg.cap(2) == "z" && !fileListItem->tags->albumArtist.isEmpty() ) ||
                   ( reg.cap(2) == "b" && !fileListItem->tags->album.isEmpty() ) ||
                   ( reg.cap(2) == "c" && !fileListItem->tags->comment.isEmpty() ) ||
                   ( reg.cap(2) == "d" && fileListItem->tags->disc != 0 ) ||
@@ -211,6 +216,7 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, cons
             path.replace( "//", "/" );
 
         path.replace( "%a", "$replace_by_artist$" );
+        path.replace( "%z", "$replace_by_albumartist$" );
         path.replace( "%b", "$replace_by_album$" );
         path.replace( "%c", "$replace_by_comment$" );
         path.replace( "%d", "$replace_by_disc$" );
@@ -220,11 +226,16 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, cons
         path.replace( "%t", "$replace_by_title$" );
         path.replace( "%y", "$replace_by_year$" );
         path.replace( "%f", "$replace_by_filename$" );
+        path.replace( "%s", "$replace_by_sourcedir$" );
 
         QString artist = ( fileListItem->tags == 0 || fileListItem->tags->artist.isEmpty() ) ? i18n("Unknown Artist") : fileListItem->tags->artist;
         artist.replace("/",",");
         path.replace( "$replace_by_artist$", artist );
 
+        QString albumArtist = ( fileListItem->tags == 0 || fileListItem->tags->albumArtist.isEmpty() ) ? i18n("Unknown Artist") : fileListItem->tags->albumArtist;
+        albumArtist.replace("/",",");
+        path.replace( "$replace_by_albumartist$", albumArtist );
+
         QString album = ( fileListItem->tags == 0 || fileListItem->tags->album.isEmpty() ) ? i18n("Unknown Album") : fileListItem->tags->album;
         album.replace("/",",");
         path.replace( "$replace_by_album$", album );
@@ -258,10 +269,13 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, cons
         filename.replace("/",",");
         path.replace( "$replace_by_filename$", filename );
 
+        QString sourcedir = fileListItem->url.directory();
+        path.replace( "$replace_by_sourcedir$", sourcedir );
+
         if( config->data.general.useVFATNames || options->outputFilesystem == "vfat" )
             path = vfatPath( path );
 
-        if( options->outputFilesystem == "ntfs" )
+        if( options->outputFilesystem == "ntfs" || options->outputFilesystem == "fuseblk" )
             path = ntfsPath( path );
 
         url = KUrl( path + "." + extension );
@@ -286,7 +300,7 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, cons
         if( config->data.general.useVFATNames || options->outputFilesystem == "vfat" )
             path = vfatPath( path );
 
-        if( options->outputFilesystem == "ntfs" )
+        if( options->outputFilesystem == "ntfs" || options->outputFilesystem == "fuseblk" )
             path = ntfsPath( path );
 
         url = changeExtension( KUrl(path), extension );
@@ -447,10 +461,12 @@ QString OutputDirectory::ntfsPath( const QString& path )
 
 void OutputDirectory::selectDir()
 {
+    QRegExp regEx( "%[abcdfgnpsty]{1,1}", Qt::CaseInsensitive );
+
     QString dir = cDir->currentText();
     QString startDir = dir;
     QString params;
-    int i = dir.indexOf( QRegExp("%[aAbBcCdDfFgGnNpPtTyY]{1,1}") );
+    int i = dir.indexOf( regEx );
     if( i != -1 && cMode->currentIndex() == 0 )
     {
         i = dir.lastIndexOf( "/", i );
@@ -475,8 +491,10 @@ void OutputDirectory::selectDir()
 
 void OutputDirectory::gotoDir()
 {
+    QRegExp regEx( "%[abcdfgnpsty]{1,1}", Qt::CaseInsensitive );
+
     QString startDir = cDir->currentText();
-    int i = startDir.indexOf( QRegExp("%[aAbBcCdDfFgGnNpPtTyY]{1,1}") );
+    int i = startDir.indexOf( regEx );
     if( i != -1 )
     {
         i = startDir.lastIndexOf( "/", i );
@@ -501,6 +519,8 @@ void OutputDirectory::modeChangedSlot( int mode )
 
 void OutputDirectory::updateMode( Mode mode )
 {
+    const int fontHeight = QFontMetrics(QApplication::font()).boundingRect("M").size().height();
+
     if( mode == MetaData )
     {
         cDir->clear();
@@ -511,7 +531,7 @@ void OutputDirectory::updateMode( Mode mode )
         pDirGoto->setEnabled( true );
         cMode->setToolTip( i18n("Name all converted files according to the specified pattern") );
         cDir->setToolTip( i18n("The following strings are wildcards that will be replaced\nby the information in the meta data:\n\n"
-                "%a - Artist\n%b - Album\n%c - Comment\n%d - Disc number\n%g - Genre\n%n - Track number\n%p - Composer\n%t - Title\n%y - Year\n%f - Original file name\n\n"
+                "%a - Artist\n%z - Album artist\n%b - Album\n%c - Comment\n%d - Disc number\n%g - Genre\n%n - Track number\n%p - Composer\n%t - Title\n%y - Year\n%f - Original file name\n%s - Path to the source directory\n\n"
                 "You may parenthesize these wildcards and surrounding characters with squared brackets ('[' and ']')\nso they will be ignored if the replacement value is empty.\n"
                 "In order to use squared brackets you will have to escape them with a backslash ('\\[' and '\\]').") );
     }
@@ -549,7 +569,7 @@ void OutputDirectory::updateMode( Mode mode )
     }
 
     // Prevent the directory combo box from beeing too wide because of the directory history
-    cDir->setMinimumWidth( 200 );
+    cDir->setMinimumWidth( 20*fontHeight );
     cDir->view()->setMinimumWidth( cDir->view()->sizeHintForColumn(0) );
 }
 
