@@ -18,7 +18,6 @@ FaacCodecWidget::FaacCodecWidget()
 {
     QGridLayout *grid = new QGridLayout( this );
     grid->setContentsMargins( 0, 0, 0, 0 );
-    grid->setSpacing( 6 );
 
     // set up encoding options selection
 
@@ -228,6 +227,8 @@ void FaacCodecWidget::modeChanged( int mode )
         dQuality->setValue( 100 );
 //         dQuality->setValue( qualityForBitrate(dQuality->value()) );
 //         qualitySpinBoxChanged( dQuality->value() );
+        sQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", 10, 500) );
+        dQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", 10, 500) );
 
 //         cBitrateMode->clear();
 //         cBitrateMode->addItem( i18n("Variable") );
@@ -244,6 +245,8 @@ void FaacCodecWidget::modeChanged( int mode )
         dQuality->setValue( 128 );
 //         dQuality->setValue( bitrateForQuality(dQuality->value()) );
 //         qualitySpinBoxChanged( dQuality->value() );
+        sQuality->setToolTip( "" );
+        dQuality->setToolTip( "" );
 
 //         cBitrateMode->clear();
 //         cBitrateMode->addItem( i18n("Average") );
