@@ -20,15 +20,12 @@ public:
     void setCurrentFormat( const QString& format );
     QString currentProfile();
     bool setCurrentProfile( const QString& profile );
-    QDomDocument customProfile();
-    bool setCustomProfile( const QString& profile, const QDomDocument& document );
     int currentDataRate();
 
 private:
     KComboBox *cMode;
     QSlider *sQuality;
     QSpinBox *dQuality;
-    KComboBox *cSamplerate;
 
     QString currentFormat; // holds the current output file format
 
@@ -39,9 +36,6 @@ private slots:
     void modeChanged( int mode );
     void qualitySliderChanged( int quality );
     void qualitySpinBoxChanged( int quality );
-
-signals:
-    void somethingChanged();
 };
 
 #endif // FAACCODECWIDGET_H
