@@ -4,6 +4,9 @@
 
 #include "../../core/codecplugin.h"
 
+#include <QWeakPointer>
+#include <QDateTime>
+
 class ConversionOptions;
 
 
@@ -18,6 +21,7 @@ public:
     ~soundkonverter_codec_faac();
 
     QString name();
+    int version();
 
     QList<ConversionPipeTrunk> codecTable();
 
@@ -31,6 +35,18 @@ public:
     unsigned int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     QStringList convertCommand( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     float parseOutput( const QString& output );
+
+private:
+    QWeakPointer<KProcess> infoProcess;
+    QString infoProcessOutputData;
+
+    int configVersion;
+    QDateTime faacLastModified;
+    bool faacHasMp4Support;
+
+private slots:
+    void infoProcessOutput();
+    void infoProcessExit( int exitCode, QProcess::ExitStatus exitStatus );
 };
 
 K_EXPORT_SOUNDKONVERTER_CODEC( faac, soundkonverter_codec_faac )
