@@ -34,7 +34,7 @@ public:
     soundkonverter_codec_ffmpeg( QObject *parent, const QStringList& args );
 
     /** Default Destructor */
-    virtual ~soundkonverter_codec_ffmpeg();
+    ~soundkonverter_codec_ffmpeg();
 
     QString name();
     int version();
@@ -46,9 +46,9 @@ public:
     bool hasInfo();
     void showInfo( QWidget *parent );
 
-    QWidget *newCodecWidget();
+    CodecWidget *newCodecWidget();
 
-    int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
+    unsigned int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     QStringList convertCommand( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     float parseOutput( const QString& output, int *length );
     float parseOutput( const QString& output );
@@ -63,6 +63,8 @@ private:
 
     int configVersion;
     bool experimentalCodecsEnabled;
+    int ffmpegVersionMajor;
+    int ffmpegVersionMinor;
     QDateTime ffmpegLastModified;
     QSet<QString> ffmpegCodecList;
 
