@@ -6,6 +6,7 @@
 
 #include <math.h>
 
+#include <QApplication>
 #include <KLocale>
 #include <KComboBox>
 #include <KLineEdit>
@@ -21,9 +22,10 @@ MusePackCodecWidget::MusePackCodecWidget()
     : CodecWidget(),
     currentFormat( "musepack" )
 {
+    const int fontHeight = QFontMetrics(QApplication::font()).boundingRect("M").size().height();
+
     QGridLayout *grid = new QGridLayout( this );
     grid->setContentsMargins( 0, 0, 0, 0 );
-    grid->setSpacing( 6 );
 
     // set up preset selection
 
@@ -65,7 +67,7 @@ MusePackCodecWidget::MusePackCodecWidget()
     QLabel *lQuality = new QLabel( i18n("Quality"), userdefinedBox );
     userdefinedTopBox->addWidget( lQuality );
 
-    userdefinedTopBox->addSpacing( 5 );
+    userdefinedTopBox->addSpacing( 0.5*fontHeight );
 
     sQuality = new QSlider( Qt::Horizontal, userdefinedBox );
     sQuality->setRange( 0, 1000 );
@@ -74,6 +76,7 @@ MusePackCodecWidget::MusePackCodecWidget()
     connect( sQuality, SIGNAL(valueChanged(int)), this, SLOT(qualitySliderChanged(int)) );
     connect( sQuality, SIGNAL(valueChanged(int)), SIGNAL(optionsChanged()) );
     userdefinedTopBox->addWidget( sQuality );
+    sQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", 0, 10) );
 
     dQuality = new QDoubleSpinBox( userdefinedBox );
     dQuality->setRange( 0, 10 );
@@ -83,6 +86,7 @@ MusePackCodecWidget::MusePackCodecWidget()
     connect( dQuality, SIGNAL(valueChanged(double)), this, SLOT(qualitySpinBoxChanged(double)) );
     connect( dQuality, SIGNAL(valueChanged(double)), SIGNAL(optionsChanged()) );
     userdefinedTopBox->addWidget( dQuality );
+    dQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", 0, 10) );
 
     userdefinedTopBox->addStretch();
 
