@@ -6,6 +6,7 @@
 
 #include <math.h>
 
+#include <QApplication>
 #include <QLayout>
 #include <QLabel>
 #include <KLocale>
@@ -20,9 +21,10 @@ NeroaacCodecWidget::NeroaacCodecWidget()
     : CodecWidget(),
     currentFormat( "m4a/aac" )
 {
+    const int fontHeight = QFontMetrics(QApplication::font()).boundingRect("M").size().height();
+
     QGridLayout *grid = new QGridLayout( this );
     grid->setContentsMargins( 0, 0, 0, 0 );
-    grid->setSpacing( 6 );
 
     // set up encoding options selection
 
@@ -54,7 +56,7 @@ NeroaacCodecWidget::NeroaacCodecWidget()
     connect( dQuality, SIGNAL(valueChanged(double)), SIGNAL(optionsChanged()) );
     topBox->addWidget( dQuality );
 
-    topBox->addSpacing( 12 );
+    topBox->addSpacing( fontHeight );
 
     QLabel *lBitrateMode = new QLabel( i18n("Bitrate mode:"), this );
     topBox->addWidget( lBitrateMode );
@@ -283,6 +285,8 @@ void NeroaacCodecWidget::modeChanged( int mode )
         dQuality->setValue( 0.5 );
 //         dQuality->setValue( qualityForBitrate(dQuality->value()) );
 //         qualitySpinBoxChanged( dQuality->value() );
+        sQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", 0, 1) );
+        dQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", 0, 1) );
 
         cBitrateMode->clear();
         cBitrateMode->addItem( i18n("Variable") );
@@ -300,6 +304,8 @@ void NeroaacCodecWidget::modeChanged( int mode )
         dQuality->setValue( 160 );
 //         dQuality->setValue( bitrateForQuality(dQuality->value()) );
 //         qualitySpinBoxChanged( dQuality->value() );
+        sQuality->setToolTip( "" );
+        dQuality->setToolTip( "" );
 
         cBitrateMode->clear();
         cBitrateMode->addItem( i18n("Average") );
