@@ -22,7 +22,6 @@ SpeexCodecWidget::SpeexCodecWidget()
 {
     QGridLayout *grid = new QGridLayout( this );
     grid->setContentsMargins( 0, 0, 0, 0 );
-    grid->setSpacing( 6 );
 
     // set up encoding options selection
 
@@ -168,6 +167,8 @@ void SpeexCodecWidget::modeChanged( int mode )
         dQuality->setValue( 8 );
 //         dQuality->setValue( qualityForBitrate(dQuality->value()) );
 //         qualitySpinBoxChanged( dQuality->value() );
+        sQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", 0, 10) );
+        dQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", 0, 10) );
     }
     else
     {
@@ -181,6 +182,8 @@ void SpeexCodecWidget::modeChanged( int mode )
         dQuality->setValue( 64 );
 //         dQuality->setValue( bitrateForQuality(dQuality->value()) );
 //         qualitySpinBoxChanged( dQuality->value() );
+        sQuality->setToolTip( "" );
+        dQuality->setToolTip( "" );
     }
 }
 
