@@ -21,8 +21,6 @@ public:
     void setCurrentFormat( const QString& format );
     QString currentProfile();
     bool setCurrentProfile( const QString& profile );
-    QDomDocument customProfile();
-    bool setCustomProfile( const QString& profile, const QDomDocument& document );
     int currentDataRate();
 
 private:
@@ -39,9 +37,6 @@ private slots:
     void modeChanged( int mode );
     void qualitySliderChanged( int quality );
     void qualitySpinBoxChanged( double quality );
-
-signals:
-    void somethingChanged();
 };
 
 #endif // SPEEXCODECWIDGET_H
\ No newline at end of file
