@@ -17,7 +17,7 @@ public:
     soundkonverter_codec_twolame( QObject *parent, const QStringList& args );
 
     /** Default Destructor */
-    virtual ~soundkonverter_codec_twolame();
+    ~soundkonverter_codec_twolame();
 
     QString name();
 
@@ -27,13 +27,11 @@ public:
     void showConfigDialog( ActionType action, const QString& codecName, QWidget *parent );
     bool hasInfo();
     void showInfo( QWidget *parent );
-    QWidget *newCodecWidget();
+    CodecWidget *newCodecWidget();
 
-    int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
+    unsigned int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     QStringList convertCommand( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     float parseOutput( const QString& output );
-
-    ConversionOptions *conversionOptionsFromXml( QDomElement conversionOptions );
 };
 
 K_EXPORT_SOUNDKONVERTER_CODEC( twolame, soundkonverter_codec_twolame )
