@@ -25,8 +25,6 @@ public:
     void setCurrentFormat( const QString& format );
     QString currentProfile();
     bool setCurrentProfile( const QString& profile );
-    QDomDocument customProfile();
-    bool setCustomProfile( const QString& profile, const QDomDocument& data );
     int currentDataRate();
 
 private:
@@ -34,10 +32,6 @@ private:
     KComboBox *cMode;
     QSpinBox *iQuality;
     QSlider *sQuality;
-    QCheckBox *chChannels;
-    KComboBox *cChannels;
-    QCheckBox *chSamplerate;
-    KComboBox *cSamplerate;
     QCheckBox *cCmdArguments;
     KLineEdit *lCmdArguments;
 
@@ -51,9 +45,6 @@ private slots:
     void modeChanged( int mode );
     void qualitySliderChanged( int quality );
     void qualitySpinBoxChanged( int quality );
-
-signals:
-    void somethingChanged();
 };
 
 #endif // TWOLAMECODECWIDGET_H
\ No newline at end of file
