@@ -10,6 +10,19 @@
 class ConversionOptions;
 class KDialog;
 class QComboBox;
+class QCheckBox;
+
+
+class Mp3GainPluginItem : public ReplayGainPluginItem
+{
+    Q_OBJECT
+public:
+    Mp3GainPluginItem( QObject *parent=0 );
+    ~Mp3GainPluginItem();
+
+    KUrl::List undoFileList;
+};
+
 
 class soundkonverter_replaygain_mp3gain : public ReplayGainPlugin
 {
@@ -19,7 +32,7 @@ public:
     soundkonverter_replaygain_mp3gain( QObject *parent, const QStringList& args );
 
     /** Default Destructor */
-    virtual ~soundkonverter_replaygain_mp3gain();
+    ~soundkonverter_replaygain_mp3gain();
 
     QString name();
 
@@ -30,16 +43,16 @@ public:
     bool hasInfo();
     void showInfo( QWidget *parent );
 
-    int apply( const KUrl::List& fileList, ApplyMode mode = Add );
+    unsigned int apply( const KUrl::List& fileList, ApplyMode mode = Add );
     float parseOutput( const QString& output );
 
 private:
-    KUrl::List undoFileList;
-
     QWeakPointer<KDialog> configDialog;
-    QComboBox *configDialogTagLabelComboBox;
+    QComboBox *configDialogTagModeComboBox;
+    QCheckBox *configDialogModifyAudioStreamCheckBox;
 
     int tagMode;
+    bool modifyAudioStream;
 
 private slots:
     /** The undo process has exited */
