@@ -119,6 +119,7 @@ void ReplayGainFileList::dropEvent( QDropEvent *event )
         else
         {
             bool canDrop = true;
+            bool showMessage = false;
             if( destination->type == ReplayGainFileListItem::Album )
             {
                 QList<QTreeWidgetItem*> q_items = selectedItems();
@@ -129,15 +130,21 @@ void ReplayGainFileList::dropEvent( QDropEvent *event )
                     if( item->codecName != destination->codecName || item->samplingRate != destination->samplingRate )
                     {
                         canDrop = false;
+                        showMessage = true;
                         break;
                     }
                 }
             }
+            else if( destination->type == ReplayGainFileListItem::Track )
+            {
+                canDrop = false;
+            }
+
             if( canDrop )
             {
                 QTreeWidget::dropEvent(event);
             }
-            else
+            else if( showMessage )
             {
                 KMessageBox::error( this, i18n("Some tracks can't be added to the album because either the codec or the sampling rate is different.") );
             }
@@ -288,14 +295,14 @@ void ReplayGainFileList::resizeEvent( QResizeEvent *event )
 int ReplayGainFileList::countDir( const QString& directory, bool recursive, int count )
 {
     QDir dir( directory );
-    dir.setFilter( QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks | QDir::Readable );
+    dir.setFilter( QDir::Files | QDir::NoDotAndDotDot | QDir::Readable );
     dir.setSorting( QDir::Unsorted );
 
     count += dir.count();
 
     if( recursive )
     {
-        dir.setFilter( QDir::Dirs | QDir::NoDotAndDotDot | QDir::NoSymLinks | QDir::Readable );
+        dir.setFilter( QDir::Dirs | QDir::NoDotAndDotDot | QDir::Readable );
 
         const QStringList list = dir.entryList();
 
@@ -320,7 +327,7 @@ int ReplayGainFileList::listDir( const QString& directory, const QStringList& fi
     QString codecName;
 
     QDir dir( directory );
-    dir.setFilter( QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::NoSymLinks | QDir::Readable );
+    dir.setFilter( QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::Readable );
     dir.setSorting( QDir::LocaleAware );
 
     const QStringList list = dir.entryList();
@@ -553,12 +560,16 @@ void ReplayGainFileList::startProcessing( ReplayGainPlugin::ApplyMode _mode )
                 switch( item->state )
                 {
                     case ReplayGainFileListItem::Waiting:
-                        break;
+                    case ReplayGainFileListItem::WaitingForReplayGain:
                     case ReplayGainFileListItem::Processing:
+                    {
                         break;
+                    }
                     case ReplayGainFileListItem::Stopped:
+                    {
                         isStopped = true;
                         break;
+                    }
                 }
             }
             if( isStopped )
@@ -578,12 +589,16 @@ void ReplayGainFileList::startProcessing( ReplayGainPlugin::ApplyMode _mode )
                     switch( child->state )
                     {
                         case ReplayGainFileListItem::Waiting:
-                            break;
+                        case ReplayGainFileListItem::WaitingForReplayGain:
                         case ReplayGainFileListItem::Processing:
+                        {
                             break;
+                        }
                         case ReplayGainFileListItem::Stopped:
+                        {
                             isStopped = true;
                             break;
+                        }
                     }
                 }
                 if( isStopped )
@@ -598,12 +613,16 @@ void ReplayGainFileList::startProcessing( ReplayGainPlugin::ApplyMode _mode )
                 switch( item->state )
                 {
                     case ReplayGainFileListItem::Waiting:
-                        break;
+                    case ReplayGainFileListItem::WaitingForReplayGain:
                     case ReplayGainFileListItem::Processing:
+                    {
                         break;
+                    }
                     case ReplayGainFileListItem::Stopped:
+                    {
                         isStopped = true;
                         break;
+                    }
                 }
             }
             if( isStopped )
@@ -641,12 +660,16 @@ void ReplayGainFileList::cancelProcess()
                 switch( item->state )
                 {
                     case ReplayGainFileListItem::Waiting:
+                    case ReplayGainFileListItem::Stopped:
+                    {
                         break;
+                    }
+                    case ReplayGainFileListItem::WaitingForReplayGain:
                     case ReplayGainFileListItem::Processing:
+                    {
                         canKill = true;
                         break;
-                    case ReplayGainFileListItem::Stopped:
-                        break;
+                    }
                 }
             }
             if( canKill )
@@ -660,12 +683,16 @@ void ReplayGainFileList::cancelProcess()
                 switch( item->state )
                 {
                     case ReplayGainFileListItem::Waiting:
+                    case ReplayGainFileListItem::Stopped:
+                    {
                         break;
+                    }
+                    case ReplayGainFileListItem::WaitingForReplayGain:
                     case ReplayGainFileListItem::Processing:
+                    {
                         canKill = true;
                         break;
-                    case ReplayGainFileListItem::Stopped:
-                        break;
+                    }
                 }
             }
             if( canKill )
@@ -683,12 +710,16 @@ void ReplayGainFileList::cancelProcess()
                         switch( child->state )
                         {
                             case ReplayGainFileListItem::Waiting:
+                            case ReplayGainFileListItem::Stopped:
+                            {
                                 break;
+                            }
+                            case ReplayGainFileListItem::WaitingForReplayGain:
                             case ReplayGainFileListItem::Processing:
+                            {
                                 canKill = true;
                                 break;
-                            case ReplayGainFileListItem::Stopped:
-                                break;
+                            }
                         }
                     }
                     if( canKill )
@@ -824,12 +855,12 @@ int ReplayGainFileList::processingCount() // TODO use ReplayGainProcessor
         item = topLevelItem(i);
         if( item->type == ReplayGainFileListItem::Track )
         {
-            if( item->state == ReplayGainFileListItem::Processing )
+            if( item->state == ReplayGainFileListItem::Processing || item->state == ReplayGainFileListItem::WaitingForReplayGain )
                 count++;
         }
         else if( item->type == ReplayGainFileListItem::Album )
         {
-            if( item->state == ReplayGainFileListItem::Processing )
+            if( item->state == ReplayGainFileListItem::Processing || item->state == ReplayGainFileListItem::WaitingForReplayGain )
             {
                 count++;
             }
@@ -838,7 +869,7 @@ int ReplayGainFileList::processingCount() // TODO use ReplayGainProcessor
                 for( int j=0; j<item->childCount(); j++ )
                 {
                     child = (ReplayGainFileListItem*)item->child(j);
-                    if( child->state == ReplayGainFileListItem::Processing )
+                    if( child->state == ReplayGainFileListItem::Processing || item->state == ReplayGainFileListItem::WaitingForReplayGain )
                     {
                         count++;
                         break;
@@ -912,22 +943,29 @@ void ReplayGainFileList::showContextMenu( const QPoint& point )
             switch( item->state )
             {
                 case ReplayGainFileListItem::Waiting:
+                {
                     canKill = false;
                     break;
+                }
+                case ReplayGainFileListItem::WaitingForReplayGain:
                 case ReplayGainFileListItem::Processing:
+                {
                     canRemove = false;
                     canStart = false;
                     canMove = false;
                     break;
+                }
                 case ReplayGainFileListItem::Stopped:
+                {
                     canKill = false;
                     break;
+                }
             }
         }
         else
         {
             canMove = false;
-            if( item->state == ReplayGainFileListItem::Processing )
+            if( item->state == ReplayGainFileListItem::Processing || item->state == ReplayGainFileListItem::WaitingForReplayGain )
             {
                 canRemove = false;
                 canStart = false;
@@ -941,15 +979,23 @@ void ReplayGainFileList::showContextMenu( const QPoint& point )
                     switch( child->state )
                     {
                         case ReplayGainFileListItem::Waiting:
+                        {
                             canKill = false;
                             break;
+                        }
+                        case ReplayGainFileListItem::WaitingForReplayGain:
                         case ReplayGainFileListItem::Processing:
+                        {
                             canRemove = false;
                             canStart = false;
+                            canMove = false;
                             break;
+                        }
                         case ReplayGainFileListItem::Stopped:
+                        {
                             canKill = false;
                             break;
+                        }
                     }
                 }
             }
