@@ -16,6 +16,7 @@
 #include <KPushButton>
 #include <KMessageBox>
 
+#include <QApplication>
 #include <QCheckBox>
 #include <QLabel>
 #include <QLayout>
@@ -23,7 +24,7 @@
 #include <QStringList>
 
 
-ReplayGainScanner::ReplayGainScanner( Config* _config, Logger* _logger, QWidget *parent, Qt::WFlags f )
+ReplayGainScanner::ReplayGainScanner( Config* _config, Logger* _logger, bool showMainWindowButton, QWidget *parent, Qt::WFlags f )
     : KDialog( parent, f ),
     config( _config ),
     logger( _logger )
@@ -33,6 +34,8 @@ ReplayGainScanner::ReplayGainScanner( Config* _config, Logger* _logger, QWidget
     setCaption( i18n("Replay Gain tool") );
     setWindowIcon( KIcon("soundkonverter-replaygain") );
 
+    const int fontHeight = QFontMetrics(QApplication::font()).boundingRect("M").size().height();
+
     QWidget *widget = new QWidget( this );
     setMainWidget( widget );
 
@@ -49,10 +52,11 @@ ReplayGainScanner::ReplayGainScanner( Config* _config, Logger* _logger, QWidget
 
     filterBox->addStretch();
 
-    cForce = new QCheckBox( i18n("Force recalculation"), this );
-    cForce->setToolTip( i18n("Recalculate Replay Gain tags for files that already have Replay Gain tags set.") );
-    filterBox->addWidget( cForce );
-
+    pShowMainWindow = new KPushButton( KIcon("soundkonverter"), i18n("Show soundKonverter main window"), widget );
+    pShowMainWindow->setVisible( showMainWindowButton );
+    filterBox->addWidget( pShowMainWindow );
+    connect( pShowMainWindow, SIGNAL(clicked()), this, SLOT(showMainWindowClicked()) );
+    
     fileList = new ReplayGainFileList( config, logger, widget );
     grid->addWidget( fileList, 1, 0 );
     connect( fileList, SIGNAL(processStarted()), this, SLOT(processStarted()) );
@@ -86,6 +90,10 @@ ReplayGainScanner::ReplayGainScanner( Config* _config, Logger* _logger, QWidget
     buttonBox->addWidget( pCancel );
     connect( pCancel, SIGNAL(clicked()), this, SLOT(cancelClicked()) );
 
+    cForce = new QCheckBox( i18n("Force recalculation"), this );
+    cForce->setToolTip( i18n("Recalculate Replay Gain tags for files that already have Replay Gain tags set.") );
+    buttonBox->addWidget( cForce );
+    
     buttonBox->addStretch();
 
     pClose = new KPushButton( KIcon("dialog-close"), i18n("Close"), widget );
@@ -97,6 +105,7 @@ ReplayGainScanner::ReplayGainScanner( Config* _config, Logger* _logger, QWidget
     connect( fileList, SIGNAL(processItem(ReplayGainFileListItem*,ReplayGainPlugin::ApplyMode)), replayGainProcessor, SLOT(add(ReplayGainFileListItem*,ReplayGainPlugin::ApplyMode)) );
     connect( fileList, SIGNAL(killItem(ReplayGainFileListItem*)), replayGainProcessor, SLOT(kill(ReplayGainFileListItem*)) );
     connect( replayGainProcessor, SIGNAL(finished(ReplayGainFileListItem*,ReplayGainFileListItem::ReturnCode)), fileList, SLOT(itemFinished(ReplayGainFileListItem*,ReplayGainFileListItem::ReturnCode)) );
+    connect( replayGainProcessor, SIGNAL(updateItem(ReplayGainFileListItem*,bool)), fileList, SLOT(updateItem(ReplayGainFileListItem*,bool)) );
 
     connect( replayGainProcessor, SIGNAL(finishedProcess(int,bool)), logger, SLOT(processCompleted(int,bool)) );
 
@@ -104,7 +113,7 @@ ReplayGainScanner::ReplayGainScanner( Config* _config, Logger* _logger, QWidget
     connect( replayGainProcessor, SIGNAL(timeFinished(float)), progressIndicator, SLOT(timeFinished(float)) );
 
 
-    setInitialSize( QSize(600,400) );
+    setInitialSize( QSize(60*fontHeight,40*fontHeight) );
     KSharedConfig::Ptr conf = KGlobal::config();
     KConfigGroup group = conf->group( "ReplayGainTool" );
     restoreDialogSize( group );
@@ -150,7 +159,7 @@ void ReplayGainScanner::showFileDialog()
     QLabel *formatHelp = new QLabel( "<a href=\"format-help\">" + i18n("Are you missing some file formats?") + "</a>", this );
     connect( formatHelp, SIGNAL(linkActivated(const QString&)), this, SLOT(showHelp()) );
 
-    fileDialog = new KFileDialog( KUrl(QDir::homePath()), filterList.join("\n"), this, formatHelp );
+    fileDialog = new KFileDialog( KUrl("kfiledialog:///soundkonverter-add-media"), filterList.join("\n"), this, formatHelp );
     fileDialog->setWindowTitle( i18n("Add Files") );
     fileDialog->setMode( KFile::Files | KFile::ExistingOnly );
     connect( fileDialog, SIGNAL(accepted()), this, SLOT(fileDialogAccepted()) );
@@ -287,6 +296,12 @@ void ReplayGainScanner::showDirDialog()
     delete dialog;
 }
 
+void ReplayGainScanner::showMainWindowClicked()
+{
+    pShowMainWindow->hide();
+    emit showMainWindow();
+}
+
 void ReplayGainScanner::addFiles( KUrl::List urls )
 {
     fileList->addFiles( urls );
